From 45ccea404689680513be3b78d2c0579f6250f963 Mon Sep 17 00:00:00 2001
From: Florian Schmaus <flo@geekplace.eu>
Date: Thu, 21 Nov 2024 18:27:04 +0100
Subject: [PATCH] pyproject.toml: explicitly set build-backend

Prior to this change, pyproject.toml would not set an build-backend,
while the project also has no setup.py.

According to some experts from Gentoo's Python project, this is a
violation of PEP 517, which states

"""
If the pyproject.toml file is absent, or the build-backend key is
missing, the source tree is not using this specification, and tools
should revert to the legacy behaviour of running setup.py (either
directly, or by implicitly invoking the setuptools.build_meta:__legacy__ backend).
"""

However, the project has no setup.py to invoke, hence Gentoo's
infrastructor for building Python packages fails without the
build-backend key being set.
---
 python/pyproject.toml | 1 +
 1 file changed, 1 insertion(+)

diff --git a/python/pyproject.toml b/python/pyproject.toml
index 0b74e16..c136b7b 100644
--- a/python/pyproject.toml
+++ b/python/pyproject.toml
@@ -1,5 +1,6 @@
 [build-system]
 requires = ['setuptools']
+build-backend = "setuptools.build_meta"
 
 
 [project]
